@@ -13,7 +13,7 @@ inline const char * gettext(const char * s) { return s; };
 #include "first.h"
 
 #ifndef FIR
-#if (defined(__APPLE__) && !defined(INT128)) || defined(__FreeBSD__)
+#if (defined(__APPLE__) && !defined(INT128)) // || defined(__FreeBSD__)
 #include <libintl.h>
 #if !defined POCKETCAS && !defined _LIBINTL_H
 #define _LIBINTL_H      1
