@@ -156,6 +156,13 @@
       {"ffunction",0,3,0,T_BLOC_END},
       {"fi",0,4,0,T_BLOC_END},
       {"filled"         ,1, _FILL_POLYGON, _INT_COLOR ,T_NUMBER},
+      {"filled_1"         ,1, _FILL_POLYGON+_POINT_WIDTH_7, _INT_COLOR ,T_NUMBER},
+      {"filled_2"         ,1, _FILL_POLYGON+_POINT_WIDTH_6, _INT_COLOR ,T_NUMBER},
+      {"filled_3"         ,1, _FILL_POLYGON+_POINT_WIDTH_5, _INT_COLOR ,T_NUMBER},
+      {"filled_4"         ,1, _FILL_POLYGON+_POINT_WIDTH_4, _INT_COLOR ,T_NUMBER},
+      {"filled_5"         ,1, _FILL_POLYGON+_POINT_WIDTH_3, _INT_COLOR ,T_NUMBER},
+      {"filled_6"         ,1, _FILL_POLYGON+_POINT_WIDTH_2, _INT_COLOR ,T_NUMBER},
+      {"filled_7"         ,1, _FILL_POLYGON, _INT_COLOR ,T_NUMBER},
       {"float"                ,0, _DOUBLE_, _INT_TYPE, T_TYPE_ID},
       {"font"         ,1,_FONT , _INT_PLOT ,T_NUMBER},
       {"for",0,2,0,T_FOR},
